package com.intershop.support.component.mycoupon.capi;

import java.util.Collection;

import com.intershop.beehive.businessobject.capi.BusinessObjectRepository;

/**
 * Repository for {@link MyCouponBO}.
 */
public interface MyCouponBORepository extends BusinessObjectRepository
{
    public static final String EXTENSION_ID = "MyCouponBORepository";

    /**
     * Creates a coupon by the given email if the email has already an active coupon, 
     * the active coupon will be returned.
     * 
     * @param email - the email for the coupon
     * 
     * @return a new {@link MyCouponBO} for the given email
     **/
    MyCouponBO createMyCouponBOByEmail(String email);

    /**
     * Counts all {@link MyCouponBO}s for the given email. 
     * 
     * @return the count of all {@link MyCouponBO} for a single email
     **/
    int countMyCouponsByEmail(String email);

    /**
     * Gets a {@link MyCouponBO} by a coupon code
     * 
     * @param couponCode - the coupon code
     * @return the {@link MyCouponBO} 
     */
    MyCouponBO getMyCouponBOByCode(String couponCode);

    /**
     * Gets a {@link MyCouponBO} by a email 
     * @param couponCode - the coupon code
     * @return list of {@link MyCouponBO} 
     */
    Collection<MyCouponBO> getMyCouponBOByEmail(String email);

    /**
     * Generates a coupon code
     * @return the generated coupon code
     */
    Collection<MyCouponBO> getAllCouponBOs();
}